@@ -32,7 +32,7 @@ bool Magick::SecurityPolicy::precision(const int precision_)
   string
     value;
 
-  value=to_string(precision_);
+  value=toString(precision_);
   return(setValue(SystemPolicyDomain,"precision",value));
 }
 
@@ -41,7 +41,7 @@ bool Magick::SecurityPolicy::maxMemoryRequest(const MagickSizeType limit_)
   string
     value;
 
-  value=to_string(limit_);
+  value=toString(limit_);
   return(setValue(SystemPolicyDomain,"max-memory-request",value));
 }
 
@@ -50,7 +50,7 @@ bool Magick::SecurityPolicy::maxProfileSize(const MagickSizeType limit_)
   string
     value;
 
-  value=to_string(limit_);
+  value=toString(limit_);
   return(setValue(SystemPolicyDomain,"max-profile-size",value));
 }
 
@@ -59,7 +59,7 @@ bool Magick::SecurityPolicy::shred(const int passes_)
   string
     value;
 
-  value=to_string(passes_);
+  value=toString(passes_);
   return(setValue(SystemPolicyDomain,"shred",value));
 }
 
@@ -79,3 +79,11 @@ bool Magick::SecurityPolicy::setValue(const PolicyDomain domain_,
   ThrowPPException(false);
   return(status != MagickFalse);
 }
+
+template <typename T>
+std::string Magick::SecurityPolicy::toString(const T& value)
+{
+  stringstream ss;
+  ss << value;
+  return ss.str();
+}
